FromBoxedPathError

Struct FromBoxedPathError 

pub struct FromBoxedPathError { /* private fields */ }
A possible error value while converting a Box<Path> to a Box<Utf8Path>.

Produced by the TryFrom<Box<Path>> implementation for Box<Utf8Path>.

Examples

use camino::{Utf8Path, FromBoxedPathError};
use std::convert::{TryFrom, TryInto};
use std::ffi::OsStr;
use std::os::unix::ffi::OsStrExt;
use std::path::Path;

let unicode_path: Box<Path> = Path::new("/valid/unicode").into();
let utf8_path: Box<Utf8Path> = unicode_path.try_into().expect("valid Unicode path succeeded");

// Paths on Unix can be non-UTF-8.
let non_unicode_str = OsStr::from_bytes(b"\xFF\xFF\xFF");
let non_unicode_path: Box<Path> = Path::new(non_unicode_str).into();
let err: FromBoxedPathError = <Box<Utf8Path>>::try_from(non_unicode_path.clone())
    .expect_err("non-Unicode path failed");
assert_eq!(err.as_path(), &*non_unicode_path);
assert_eq!(err.into_boxed_path(), non_unicode_path);

Implementations

Source

impl FromBoxedPathError

pub fn as_path(&self) -> &Path

Returns the Path slice that was attempted to be converted to Box<Utf8Path>.

pub fn into_boxed_path(self) -> Box<Path>

Returns the Box<Path> that was attempted to be converted to Box<Utf8Path>.

pub fn from_path_error(&self) -> FromPathError

Fetches a FromPathError for more about the conversion failure.

At the moment this struct does not contain any additional information, but is provided for completeness.

pub fn into_io_error(self) -> Error

Converts self into a std::io::Error with kind InvalidData.

Many users of FromBoxedPathError will want to convert it into an io::Error. This is a convenience method to do that.